# Generated by Django 3.2.11 on 2022-05-23 01:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_omise', '0003_alter_source_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='charge',
            name='status',
            field=models.CharField(choices=[('failed', 'Failed'), ('expired', 'Expired'), ('pending', 'Pending'), ('reversed', 'Reversed'), ('successful', 'Successful'), ('unknown', 'Unknown')], help_text='Status of this charge.', max_length=10),
        ),
        migrations.AlterField(
            model_name='source',
            name='charge_status',
            field=models.CharField(choices=[('failed', 'Failed'), ('expired', 'Expired'), ('pending', 'Pending'), ('reversed', 'Reversed'), ('successful', 'Successful'), ('unknown', 'Unknown')], help_text='Status of charge created using this source (if any)', max_length=10),
        ),
    ]
